:mod:`anyconfig.schema`
========================

.. automodule:: anyconfig.schema
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   anyconfig.schema.common
   anyconfig.schema.default
   anyconfig.schema.jsonschema
